var files =
[
    [ "adelaycontroller.cpp", "adelaycontroller_8cpp.html", "adelaycontroller_8cpp" ],
    [ "adelaycontroller.h", "adelaycontroller_8h.html", [
      [ "IDelayTestController", "classSteinberg_1_1Vst_1_1IDelayTestController.html", "classSteinberg_1_1Vst_1_1IDelayTestController" ],
      [ "ADelayController", "classSteinberg_1_1Vst_1_1ADelayController.html", "classSteinberg_1_1Vst_1_1ADelayController" ]
    ] ],
    [ "adelayids.h", "adelayids_8h.html", "adelayids_8h" ],
    [ "adelayprocessor.cpp", "adelayprocessor_8cpp.html", null ],
    [ "adelayprocessor.h", "adelayprocessor_8h.html", [
      [ "ADelayProcessor", "classSteinberg_1_1Vst_1_1ADelayProcessor.html", "classSteinberg_1_1Vst_1_1ADelayProcessor" ]
    ] ],
    [ "again.cpp", "again_8cpp.html", null ],
    [ "again.h", "again_8h.html", [
      [ "AGain", "classSteinberg_1_1Vst_1_1AGain.html", "classSteinberg_1_1Vst_1_1AGain" ]
    ] ],
    [ "againaax.cpp", "againaax_8cpp.html", "againaax_8cpp" ],
    [ "againcids.h", "againcids_8h.html", "againcids_8h" ],
    [ "againcontroller.cpp", "againcontroller_8cpp.html", null ],
    [ "againcontroller.h", "againcontroller_8h.html", [
      [ "AGainUIMessageController", "classAGainUIMessageController.html", null ],
      [ "AGainController", "classSteinberg_1_1Vst_1_1AGainController.html", "classSteinberg_1_1Vst_1_1AGainController" ]
    ] ],
    [ "againentry.cpp", "againentry_8cpp.html", "againentry_8cpp" ],
    [ "againentry_vst2.cpp", "againentry__vst2_8cpp.html", "againentry__vst2_8cpp" ],
    [ "againparamids.h", "againparamids_8h.html", "againparamids_8h" ],
    [ "againprocess.h", "againprocess_8h.html", null ],
    [ "againsidechain.cpp", "againsidechain_8cpp.html", null ],
    [ "againsidechain.h", "againsidechain_8h.html", [
      [ "AGainWithSideChain", "classSteinberg_1_1Vst_1_1AGainWithSideChain.html", "classSteinberg_1_1Vst_1_1AGainWithSideChain" ]
    ] ],
    [ "againuimessagecontroller.h", "againuimessagecontroller_8h.html", [
      [ "AGainUIMessageController", "classSteinberg_1_1Vst_1_1AGainUIMessageController.html", "classSteinberg_1_1Vst_1_1AGainUIMessageController" ]
    ] ],
    [ "audiohost.cpp", "audiohost_8cpp.html", "audiohost_8cpp" ],
    [ "audiohost.h", "audiohost_8h.html", [
      [ "App", "classSteinberg_1_1Vst_1_1AudioHost_1_1App.html", "classSteinberg_1_1Vst_1_1AudioHost_1_1App" ]
    ] ],
    [ "again_auv3/audiounitconfig.h", "again__auv3_2audiounitconfig_8h.html", "again__auv3_2audiounitconfig_8h" ],
    [ "note_expression_synth_auv3/audiounitconfig.h", "note__expression__synth__auv3_2audiounitconfig_8h.html", "note__expression__synth__auv3_2audiounitconfig_8h" ],
    [ "brownnoise.h", "brownnoise_8h.html", [
      [ "BrownNoise", "classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1BrownNoise.html", "classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1BrownNoise" ]
    ] ],
    [ "cids.h", "cids_8h.html", "cids_8h" ],
    [ "doc.h", "doc_8h.html", null ],
    [ "editorhost.cpp", "editorhost_8cpp.html", "editorhost_8cpp" ],
    [ "editorhost.h", "editorhost_8h.html", [
      [ "App", "classSteinberg_1_1Vst_1_1EditorHost_1_1App.html", "classSteinberg_1_1Vst_1_1EditorHost_1_1App" ]
    ] ],
    [ "editorsizecontroller.cpp", "editorsizecontroller_8cpp.html", null ],
    [ "editorsizecontroller.h", "editorsizecontroller_8h.html", "editorsizecontroller_8h" ],
    [ "eventlistcheck.cpp", "eventlistcheck_8cpp.html", null ],
    [ "eventlistcheck.h", "eventlistcheck_8h.html", [
      [ "EventListCheck", "classEventListCheck.html", "classEventListCheck" ]
    ] ],
    [ "eventlogdatabrowsersource.cpp", "eventlogdatabrowsersource_8cpp.html", null ],
    [ "eventlogdatabrowsersource.h", "eventlogdatabrowsersource_8h.html", [
      [ "EventLogDataBrowserSource", "classVSTGUI_1_1EventLogDataBrowserSource.html", "classVSTGUI_1_1EventLogDataBrowserSource" ]
    ] ],
    [ "eventlogger.cpp", "eventlogger_8cpp.html", null ],
    [ "eventlogger.h", "eventlogger_8h.html", [
      [ "EventLogger", "classEventLogger.html", "classEventLogger" ]
    ] ],
    [ "exampletest.cpp", "exampletest_8cpp.html", null ],
    [ "adelay/source/factory.cpp", "adelay_2source_2factory_8cpp.html", "adelay_2source_2factory_8cpp" ],
    [ "hostchecker/source/factory.cpp", "hostchecker_2source_2factory_8cpp.html", null ],
    [ "note_expression_synth/source/factory.cpp", "note__expression__synth_2source_2factory_8cpp.html", "note__expression__synth_2source_2factory_8cpp" ],
    [ "pitchnames/source/factory.cpp", "pitchnames_2source_2factory_8cpp.html", "pitchnames_2source_2factory_8cpp" ],
    [ "filter.h", "filter_8h.html", "filter_8h" ],
    [ "helpers.h", "helpers_8h.html", "helpers_8h" ],
    [ "hostcheck.cpp", "hostcheck_8cpp.html", null ],
    [ "hostcheck.h", "hostcheck_8h.html", [
      [ "HostCheck", "classHostCheck.html", "classHostCheck" ]
    ] ],
    [ "hostcheckercontroller.cpp", "hostcheckercontroller_8cpp.html", "hostcheckercontroller_8cpp" ],
    [ "hostcheckercontroller.h", "hostcheckercontroller_8h.html", "hostcheckercontroller_8h" ],
    [ "hostcheckerprocessor.cpp", "hostcheckerprocessor_8cpp.html", "hostcheckerprocessor_8cpp" ],
    [ "hostcheckerprocessor.h", "hostcheckerprocessor_8h.html", "hostcheckerprocessor_8h" ],
    [ "logevents.h", "logevents_8h.html", "logevents_8h" ],
    [ "logscale.h", "logscale_8h.html", [
      [ "LogScale", "classSteinberg_1_1Vst_1_1LogScale.html", "classSteinberg_1_1Vst_1_1LogScale" ],
      [ "LogScaleParameter", "classSteinberg_1_1Vst_1_1LogScaleParameter.html", "classSteinberg_1_1Vst_1_1LogScaleParameter" ]
    ] ],
    [ "main.cpp", "main_8cpp.html", "main_8cpp" ],
    [ "main.m", "main_8m.html", "main_8m" ],
    [ "mdaAmbienceController.cpp", "mdaAmbienceController_8cpp.html", null ],
    [ "mdaAmbienceController.h", "mdaAmbienceController_8h.html", [
      [ "AmbienceController", "classSteinberg_1_1Vst_1_1mda_1_1AmbienceController.html", "classSteinberg_1_1Vst_1_1mda_1_1AmbienceController" ]
    ] ],
    [ "mdaAmbienceProcessor.cpp", "mdaAmbienceProcessor_8cpp.html", null ],
    [ "mdaAmbienceProcessor.h", "mdaAmbienceProcessor_8h.html", [
      [ "AmbienceProcessor", "classSteinberg_1_1Vst_1_1mda_1_1AmbienceProcessor.html", "classSteinberg_1_1Vst_1_1mda_1_1AmbienceProcessor" ]
    ] ],
    [ "mdaBandistoController.cpp", "mdaBandistoController_8cpp.html", null ],
    [ "mdaBandistoController.h", "mdaBandistoController_8h.html", [
      [ "BandistoController", "classSteinberg_1_1Vst_1_1mda_1_1BandistoController.html", "classSteinberg_1_1Vst_1_1mda_1_1BandistoController" ]
    ] ],
    [ "mdaBandistoProcessor.cpp", "mdaBandistoProcessor_8cpp.html", null ],
    [ "mdaBandistoProcessor.h", "mdaBandistoProcessor_8h.html", [
      [ "BandistoProcessor", "classSteinberg_1_1Vst_1_1mda_1_1BandistoProcessor.html", "classSteinberg_1_1Vst_1_1mda_1_1BandistoProcessor" ]
    ] ],
    [ "mdaBaseController.cpp", "mdaBaseController_8cpp.html", null ],
    [ "mdaBaseController.h", "mdaBaseController_8h.html", [
      [ "BaseController", "classSteinberg_1_1Vst_1_1mda_1_1BaseController.html", "classSteinberg_1_1Vst_1_1mda_1_1BaseController" ]
    ] ],
    [ "mdaBaseProcessor.cpp", "mdaBaseProcessor_8cpp.html", "mdaBaseProcessor_8cpp" ],
    [ "mdaBaseProcessor.h", "mdaBaseProcessor_8h.html", "mdaBaseProcessor_8h" ],
    [ "mdaBeatBoxController.cpp", "mdaBeatBoxController_8cpp.html", null ],
    [ "mdaBeatBoxController.h", "mdaBeatBoxController_8h.html", [
      [ "BeatBoxController", "classSteinberg_1_1Vst_1_1mda_1_1BeatBoxController.html", "classSteinberg_1_1Vst_1_1mda_1_1BeatBoxController" ]
    ] ],
    [ "mdaBeatBoxProcessor.cpp", "mdaBeatBoxProcessor_8cpp.html", null ],
    [ "mdaBeatBoxProcessor.h", "mdaBeatBoxProcessor_8h.html", [
      [ "BeatBoxProcessor", "classSteinberg_1_1Vst_1_1mda_1_1BeatBoxProcessor.html", "classSteinberg_1_1Vst_1_1mda_1_1BeatBoxProcessor" ]
    ] ],
    [ "mdaComboController.cpp", "mdaComboController_8cpp.html", null ],
    [ "mdaComboController.h", "mdaComboController_8h.html", [
      [ "ComboController", "classSteinberg_1_1Vst_1_1mda_1_1ComboController.html", "classSteinberg_1_1Vst_1_1mda_1_1ComboController" ]
    ] ],
    [ "mdaComboProcessor.cpp", "mdaComboProcessor_8cpp.html", null ],
    [ "mdaComboProcessor.h", "mdaComboProcessor_8h.html", [
      [ "ComboProcessor", "classSteinberg_1_1Vst_1_1mda_1_1ComboProcessor.html", "classSteinberg_1_1Vst_1_1mda_1_1ComboProcessor" ]
    ] ],
    [ "mdaDeEsserController.cpp", "mdaDeEsserController_8cpp.html", null ],
    [ "mdaDeEsserController.h", "mdaDeEsserController_8h.html", [
      [ "DeEsserController", "classSteinberg_1_1Vst_1_1mda_1_1DeEsserController.html", "classSteinberg_1_1Vst_1_1mda_1_1DeEsserController" ]
    ] ],
    [ "mdaDeEsserProcessor.cpp", "mdaDeEsserProcessor_8cpp.html", null ],
    [ "mdaDeEsserProcessor.h", "mdaDeEsserProcessor_8h.html", [
      [ "DeEsserProcessor", "classSteinberg_1_1Vst_1_1mda_1_1DeEsserProcessor.html", "classSteinberg_1_1Vst_1_1mda_1_1DeEsserProcessor" ]
    ] ],
    [ "mdaDegradeController.cpp", "mdaDegradeController_8cpp.html", null ],
    [ "mdaDegradeController.h", "mdaDegradeController_8h.html", [
      [ "DegradeController", "classSteinberg_1_1Vst_1_1mda_1_1DegradeController.html", "classSteinberg_1_1Vst_1_1mda_1_1DegradeController" ]
    ] ],
    [ "mdaDegradeProcessor.cpp", "mdaDegradeProcessor_8cpp.html", null ],
    [ "mdaDegradeProcessor.h", "mdaDegradeProcessor_8h.html", [
      [ "DegradeProcessor", "classSteinberg_1_1Vst_1_1mda_1_1DegradeProcessor.html", "classSteinberg_1_1Vst_1_1mda_1_1DegradeProcessor" ]
    ] ],
    [ "mdaDelayController.cpp", "mdaDelayController_8cpp.html", null ],
    [ "mdaDelayController.h", "mdaDelayController_8h.html", [
      [ "DelayController", "classSteinberg_1_1Vst_1_1mda_1_1DelayController.html", "classSteinberg_1_1Vst_1_1mda_1_1DelayController" ]
    ] ],
    [ "mdaDelayProcessor.cpp", "mdaDelayProcessor_8cpp.html", null ],
    [ "mdaDelayProcessor.h", "mdaDelayProcessor_8h.html", [
      [ "DelayProcessor", "classSteinberg_1_1Vst_1_1mda_1_1DelayProcessor.html", "classSteinberg_1_1Vst_1_1mda_1_1DelayProcessor" ]
    ] ],
    [ "mdaDetuneController.cpp", "mdaDetuneController_8cpp.html", null ],
    [ "mdaDetuneController.h", "mdaDetuneController_8h.html", [
      [ "DetuneController", "classSteinberg_1_1Vst_1_1mda_1_1DetuneController.html", "classSteinberg_1_1Vst_1_1mda_1_1DetuneController" ]
    ] ],
    [ "mdaDetuneProcessor.cpp", "mdaDetuneProcessor_8cpp.html", "mdaDetuneProcessor_8cpp" ],
    [ "mdaDetuneProcessor.h", "mdaDetuneProcessor_8h.html", [
      [ "DetuneProcessor", "classSteinberg_1_1Vst_1_1mda_1_1DetuneProcessor.html", "classSteinberg_1_1Vst_1_1mda_1_1DetuneProcessor" ]
    ] ],
    [ "mdaDitherController.cpp", "mdaDitherController_8cpp.html", null ],
    [ "mdaDitherController.h", "mdaDitherController_8h.html", [
      [ "DitherController", "classSteinberg_1_1Vst_1_1mda_1_1DitherController.html", "classSteinberg_1_1Vst_1_1mda_1_1DitherController" ]
    ] ],
    [ "mdaDitherProcessor.cpp", "mdaDitherProcessor_8cpp.html", null ],
    [ "mdaDitherProcessor.h", "mdaDitherProcessor_8h.html", [
      [ "DitherProcessor", "classSteinberg_1_1Vst_1_1mda_1_1DitherProcessor.html", "classSteinberg_1_1Vst_1_1mda_1_1DitherProcessor" ]
    ] ],
    [ "mdaDubDelayController.cpp", "mdaDubDelayController_8cpp.html", null ],
    [ "mdaDubDelayController.h", "mdaDubDelayController_8h.html", [
      [ "DubDelayController", "classSteinberg_1_1Vst_1_1mda_1_1DubDelayController.html", "classSteinberg_1_1Vst_1_1mda_1_1DubDelayController" ]
    ] ],
    [ "mdaDubDelayProcessor.cpp", "mdaDubDelayProcessor_8cpp.html", null ],
    [ "mdaDubDelayProcessor.h", "mdaDubDelayProcessor_8h.html", [
      [ "DubDelayProcessor", "classSteinberg_1_1Vst_1_1mda_1_1DubDelayProcessor.html", "classSteinberg_1_1Vst_1_1mda_1_1DubDelayProcessor" ]
    ] ],
    [ "mdaDX10Controller.cpp", "mdaDX10Controller_8cpp.html", null ],
    [ "mdaDX10Controller.h", "mdaDX10Controller_8h.html", [
      [ "DX10Controller", "classSteinberg_1_1Vst_1_1mda_1_1DX10Controller.html", "classSteinberg_1_1Vst_1_1mda_1_1DX10Controller" ]
    ] ],
    [ "mdaDX10Processor.cpp", "mdaDX10Processor_8cpp.html", "mdaDX10Processor_8cpp" ],
    [ "mdaDX10Processor.h", "mdaDX10Processor_8h.html", [
      [ "DX10Processor", "classSteinberg_1_1Vst_1_1mda_1_1DX10Processor.html", "classSteinberg_1_1Vst_1_1mda_1_1DX10Processor" ],
      [ "VOICE", "structSteinberg_1_1Vst_1_1mda_1_1DX10Processor_1_1VOICE.html", "structSteinberg_1_1Vst_1_1mda_1_1DX10Processor_1_1VOICE" ]
    ] ],
    [ "mdaDynamicsController.cpp", "mdaDynamicsController_8cpp.html", null ],
    [ "mdaDynamicsController.h", "mdaDynamicsController_8h.html", [
      [ "DynamicsController", "classSteinberg_1_1Vst_1_1mda_1_1DynamicsController.html", "classSteinberg_1_1Vst_1_1mda_1_1DynamicsController" ]
    ] ],
    [ "mdaDynamicsProcessor.cpp", "mdaDynamicsProcessor_8cpp.html", null ],
    [ "mdaDynamicsProcessor.h", "mdaDynamicsProcessor_8h.html", [
      [ "DynamicsProcessor", "classSteinberg_1_1Vst_1_1mda_1_1DynamicsProcessor.html", "classSteinberg_1_1Vst_1_1mda_1_1DynamicsProcessor" ]
    ] ],
    [ "mdaEPianoController.cpp", "mdaEPianoController_8cpp.html", null ],
    [ "mdaEPianoController.h", "mdaEPianoController_8h.html", [
      [ "EPianoController", "classSteinberg_1_1Vst_1_1mda_1_1EPianoController.html", "classSteinberg_1_1Vst_1_1mda_1_1EPianoController" ]
    ] ],
    [ "mdaEPianoData.h", "mdaEPianoData_8h.html", "mdaEPianoData_8h" ],
    [ "mdaEPianoProcessor.cpp", "mdaEPianoProcessor_8cpp.html", "mdaEPianoProcessor_8cpp" ],
    [ "mdaEPianoProcessor.h", "mdaEPianoProcessor_8h.html", [
      [ "EPianoProcessor", "classSteinberg_1_1Vst_1_1mda_1_1EPianoProcessor.html", "classSteinberg_1_1Vst_1_1mda_1_1EPianoProcessor" ],
      [ "VOICE", "structSteinberg_1_1Vst_1_1mda_1_1EPianoProcessor_1_1VOICE.html", "structSteinberg_1_1Vst_1_1mda_1_1EPianoProcessor_1_1VOICE" ],
      [ "KGRP", "structSteinberg_1_1Vst_1_1mda_1_1EPianoProcessor_1_1KGRP.html", "structSteinberg_1_1Vst_1_1mda_1_1EPianoProcessor_1_1KGRP" ]
    ] ],
    [ "mdafactory.cpp", "mdafactory_8cpp.html", "mdafactory_8cpp" ],
    [ "mdaImageController.cpp", "mdaImageController_8cpp.html", null ],
    [ "mdaImageController.h", "mdaImageController_8h.html", [
      [ "ImageController", "classSteinberg_1_1Vst_1_1mda_1_1ImageController.html", "classSteinberg_1_1Vst_1_1mda_1_1ImageController" ]
    ] ],
    [ "mdaImageProcessor.cpp", "mdaImageProcessor_8cpp.html", null ],
    [ "mdaImageProcessor.h", "mdaImageProcessor_8h.html", [
      [ "ImageProcessor", "classSteinberg_1_1Vst_1_1mda_1_1ImageProcessor.html", "classSteinberg_1_1Vst_1_1mda_1_1ImageProcessor" ]
    ] ],
    [ "mdaJX10Controller.cpp", "mdaJX10Controller_8cpp.html", null ],
    [ "mdaJX10Controller.h", "mdaJX10Controller_8h.html", [
      [ "JX10Controller", "classSteinberg_1_1Vst_1_1mda_1_1JX10Controller.html", "classSteinberg_1_1Vst_1_1mda_1_1JX10Controller" ]
    ] ],
    [ "mdaJX10Processor.cpp", "mdaJX10Processor_8cpp.html", "mdaJX10Processor_8cpp" ],
    [ "mdaJX10Processor.h", "mdaJX10Processor_8h.html", [
      [ "JX10Processor", "classSteinberg_1_1Vst_1_1mda_1_1JX10Processor.html", "classSteinberg_1_1Vst_1_1mda_1_1JX10Processor" ],
      [ "VOICE", "structSteinberg_1_1Vst_1_1mda_1_1JX10Processor_1_1VOICE.html", "structSteinberg_1_1Vst_1_1mda_1_1JX10Processor_1_1VOICE" ]
    ] ],
    [ "mdaLeslieController.cpp", "mdaLeslieController_8cpp.html", null ],
    [ "mdaLeslieController.h", "mdaLeslieController_8h.html", [
      [ "LeslieController", "classSteinberg_1_1Vst_1_1mda_1_1LeslieController.html", "classSteinberg_1_1Vst_1_1mda_1_1LeslieController" ]
    ] ],
    [ "mdaLeslieProcessor.cpp", "mdaLeslieProcessor_8cpp.html", null ],
    [ "mdaLeslieProcessor.h", "mdaLeslieProcessor_8h.html", [
      [ "LeslieProcessor", "classSteinberg_1_1Vst_1_1mda_1_1LeslieProcessor.html", "classSteinberg_1_1Vst_1_1mda_1_1LeslieProcessor" ]
    ] ],
    [ "mdaLimiterController.cpp", "mdaLimiterController_8cpp.html", null ],
    [ "mdaLimiterController.h", "mdaLimiterController_8h.html", [
      [ "LimiterController", "classSteinberg_1_1Vst_1_1mda_1_1LimiterController.html", "classSteinberg_1_1Vst_1_1mda_1_1LimiterController" ]
    ] ],
    [ "mdaLimiterProcessor.cpp", "mdaLimiterProcessor_8cpp.html", null ],
    [ "mdaLimiterProcessor.h", "mdaLimiterProcessor_8h.html", [
      [ "LimiterProcessor", "classSteinberg_1_1Vst_1_1mda_1_1LimiterProcessor.html", "classSteinberg_1_1Vst_1_1mda_1_1LimiterProcessor" ]
    ] ],
    [ "mdaLoudnessController.cpp", "mdaLoudnessController_8cpp.html", null ],
    [ "mdaLoudnessController.h", "mdaLoudnessController_8h.html", [
      [ "LoudnessController", "classSteinberg_1_1Vst_1_1mda_1_1LoudnessController.html", "classSteinberg_1_1Vst_1_1mda_1_1LoudnessController" ]
    ] ],
    [ "mdaLoudnessProcessor.cpp", "mdaLoudnessProcessor_8cpp.html", null ],
    [ "mdaLoudnessProcessor.h", "mdaLoudnessProcessor_8h.html", [
      [ "LoudnessProcessor", "classSteinberg_1_1Vst_1_1mda_1_1LoudnessProcessor.html", "classSteinberg_1_1Vst_1_1mda_1_1LoudnessProcessor" ]
    ] ],
    [ "mdaMultiBandController.cpp", "mdaMultiBandController_8cpp.html", null ],
    [ "mdaMultiBandController.h", "mdaMultiBandController_8h.html", [
      [ "MultiBandController", "classSteinberg_1_1Vst_1_1mda_1_1MultiBandController.html", "classSteinberg_1_1Vst_1_1mda_1_1MultiBandController" ]
    ] ],
    [ "mdaMultiBandProcessor.cpp", "mdaMultiBandProcessor_8cpp.html", null ],
    [ "mdaMultiBandProcessor.h", "mdaMultiBandProcessor_8h.html", [
      [ "MultiBandProcessor", "classSteinberg_1_1Vst_1_1mda_1_1MultiBandProcessor.html", "classSteinberg_1_1Vst_1_1mda_1_1MultiBandProcessor" ]
    ] ],
    [ "mdaOverdriveController.cpp", "mdaOverdriveController_8cpp.html", null ],
    [ "mdaOverdriveController.h", "mdaOverdriveController_8h.html", [
      [ "OverdriveController", "classSteinberg_1_1Vst_1_1mda_1_1OverdriveController.html", "classSteinberg_1_1Vst_1_1mda_1_1OverdriveController" ]
    ] ],
    [ "mdaOverdriveProcessor.cpp", "mdaOverdriveProcessor_8cpp.html", null ],
    [ "mdaOverdriveProcessor.h", "mdaOverdriveProcessor_8h.html", [
      [ "OverdriveProcessor", "classSteinberg_1_1Vst_1_1mda_1_1OverdriveProcessor.html", "classSteinberg_1_1Vst_1_1mda_1_1OverdriveProcessor" ]
    ] ],
    [ "mdaParameter.cpp", "mdaParameter_8cpp.html", null ],
    [ "mdaParameter.h", "mdaParameter_8h.html", [
      [ "BaseParameter", "classSteinberg_1_1Vst_1_1mda_1_1BaseParameter.html", "classSteinberg_1_1Vst_1_1mda_1_1BaseParameter" ],
      [ "IndexedParameter", "classSteinberg_1_1Vst_1_1mda_1_1IndexedParameter.html", "classSteinberg_1_1Vst_1_1mda_1_1IndexedParameter" ],
      [ "ScaledParameter", "classSteinberg_1_1Vst_1_1mda_1_1ScaledParameter.html", "classSteinberg_1_1Vst_1_1mda_1_1ScaledParameter" ]
    ] ],
    [ "mdaPianoController.cpp", "mdaPianoController_8cpp.html", null ],
    [ "mdaPianoController.h", "mdaPianoController_8h.html", [
      [ "PianoController", "classSteinberg_1_1Vst_1_1mda_1_1PianoController.html", "classSteinberg_1_1Vst_1_1mda_1_1PianoController" ]
    ] ],
    [ "mdaPianoData.h", "mdaPianoData_8h.html", "mdaPianoData_8h" ],
    [ "mdaPianoProcessor.cpp", "mdaPianoProcessor_8cpp.html", "mdaPianoProcessor_8cpp" ],
    [ "mdaPianoProcessor.h", "mdaPianoProcessor_8h.html", [
      [ "PianoProcessor", "classSteinberg_1_1Vst_1_1mda_1_1PianoProcessor.html", "classSteinberg_1_1Vst_1_1mda_1_1PianoProcessor" ],
      [ "VOICE", "structSteinberg_1_1Vst_1_1mda_1_1PianoProcessor_1_1VOICE.html", "structSteinberg_1_1Vst_1_1mda_1_1PianoProcessor_1_1VOICE" ],
      [ "KGRP", "structSteinberg_1_1Vst_1_1mda_1_1PianoProcessor_1_1KGRP.html", "structSteinberg_1_1Vst_1_1mda_1_1PianoProcessor_1_1KGRP" ]
    ] ],
    [ "mdaRePsychoController.cpp", "mdaRePsychoController_8cpp.html", null ],
    [ "mdaRePsychoController.h", "mdaRePsychoController_8h.html", [
      [ "RePsychoController", "classSteinberg_1_1Vst_1_1mda_1_1RePsychoController.html", "classSteinberg_1_1Vst_1_1mda_1_1RePsychoController" ]
    ] ],
    [ "mdaRePsychoProcessor.cpp", "mdaRePsychoProcessor_8cpp.html", null ],
    [ "mdaRePsychoProcessor.h", "mdaRePsychoProcessor_8h.html", [
      [ "RePsychoProcessor", "classSteinberg_1_1Vst_1_1mda_1_1RePsychoProcessor.html", "classSteinberg_1_1Vst_1_1mda_1_1RePsychoProcessor" ]
    ] ],
    [ "mdaRezFilterController.cpp", "mdaRezFilterController_8cpp.html", null ],
    [ "mdaRezFilterController.h", "mdaRezFilterController_8h.html", [
      [ "RezFilterController", "classSteinberg_1_1Vst_1_1mda_1_1RezFilterController.html", "classSteinberg_1_1Vst_1_1mda_1_1RezFilterController" ]
    ] ],
    [ "mdaRezFilterProcessor.cpp", "mdaRezFilterProcessor_8cpp.html", null ],
    [ "mdaRezFilterProcessor.h", "mdaRezFilterProcessor_8h.html", [
      [ "RezFilterProcessor", "classSteinberg_1_1Vst_1_1mda_1_1RezFilterProcessor.html", "classSteinberg_1_1Vst_1_1mda_1_1RezFilterProcessor" ]
    ] ],
    [ "mdaRingModController.cpp", "mdaRingModController_8cpp.html", null ],
    [ "mdaRingModController.h", "mdaRingModController_8h.html", [
      [ "RingModController", "classSteinberg_1_1Vst_1_1mda_1_1RingModController.html", "classSteinberg_1_1Vst_1_1mda_1_1RingModController" ]
    ] ],
    [ "mdaRingModProcessor.cpp", "mdaRingModProcessor_8cpp.html", null ],
    [ "mdaRingModProcessor.h", "mdaRingModProcessor_8h.html", [
      [ "RingModProcessor", "classSteinberg_1_1Vst_1_1mda_1_1RingModProcessor.html", "classSteinberg_1_1Vst_1_1mda_1_1RingModProcessor" ]
    ] ],
    [ "mdaRoundPanController.cpp", "mdaRoundPanController_8cpp.html", null ],
    [ "mdaRoundPanController.h", "mdaRoundPanController_8h.html", [
      [ "RoundPanController", "classSteinberg_1_1Vst_1_1mda_1_1RoundPanController.html", "classSteinberg_1_1Vst_1_1mda_1_1RoundPanController" ]
    ] ],
    [ "mdaRoundPanProcessor.cpp", "mdaRoundPanProcessor_8cpp.html", null ],
    [ "mdaRoundPanProcessor.h", "mdaRoundPanProcessor_8h.html", [
      [ "RoundPanProcessor", "classSteinberg_1_1Vst_1_1mda_1_1RoundPanProcessor.html", "classSteinberg_1_1Vst_1_1mda_1_1RoundPanProcessor" ]
    ] ],
    [ "mdaShepardController.cpp", "mdaShepardController_8cpp.html", null ],
    [ "mdaShepardController.h", "mdaShepardController_8h.html", [
      [ "ShepardController", "classSteinberg_1_1Vst_1_1mda_1_1ShepardController.html", "classSteinberg_1_1Vst_1_1mda_1_1ShepardController" ]
    ] ],
    [ "mdaShepardProcessor.cpp", "mdaShepardProcessor_8cpp.html", null ],
    [ "mdaShepardProcessor.h", "mdaShepardProcessor_8h.html", [
      [ "ShepardProcessor", "classSteinberg_1_1Vst_1_1mda_1_1ShepardProcessor.html", "classSteinberg_1_1Vst_1_1mda_1_1ShepardProcessor" ]
    ] ],
    [ "mdaSpecMeterController.cpp", "mdaSpecMeterController_8cpp.html", null ],
    [ "mdaSpecMeterController.h", "mdaSpecMeterController_8h.html", [
      [ "SpecMeterController", "classSteinberg_1_1Vst_1_1mda_1_1SpecMeterController.html", "classSteinberg_1_1Vst_1_1mda_1_1SpecMeterController" ]
    ] ],
    [ "mdaSpecMeterProcessor.cpp", "mdaSpecMeterProcessor_8cpp.html", "mdaSpecMeterProcessor_8cpp" ],
    [ "mdaSpecMeterProcessor.h", "mdaSpecMeterProcessor_8h.html", [
      [ "SpecMeterProcessor", "classSteinberg_1_1Vst_1_1mda_1_1SpecMeterProcessor.html", "classSteinberg_1_1Vst_1_1mda_1_1SpecMeterProcessor" ]
    ] ],
    [ "mdaSplitterController.cpp", "mdaSplitterController_8cpp.html", null ],
    [ "mdaSplitterController.h", "mdaSplitterController_8h.html", [
      [ "SplitterController", "classSteinberg_1_1Vst_1_1mda_1_1SplitterController.html", "classSteinberg_1_1Vst_1_1mda_1_1SplitterController" ]
    ] ],
    [ "mdaSplitterProcessor.cpp", "mdaSplitterProcessor_8cpp.html", null ],
    [ "mdaSplitterProcessor.h", "mdaSplitterProcessor_8h.html", [
      [ "SplitterProcessor", "classSteinberg_1_1Vst_1_1mda_1_1SplitterProcessor.html", "classSteinberg_1_1Vst_1_1mda_1_1SplitterProcessor" ]
    ] ],
    [ "mdaStereoController.cpp", "mdaStereoController_8cpp.html", null ],
    [ "mdaStereoController.h", "mdaStereoController_8h.html", [
      [ "StereoController", "classSteinberg_1_1Vst_1_1mda_1_1StereoController.html", "classSteinberg_1_1Vst_1_1mda_1_1StereoController" ]
    ] ],
    [ "mdaStereoProcessor.cpp", "mdaStereoProcessor_8cpp.html", null ],
    [ "mdaStereoProcessor.h", "mdaStereoProcessor_8h.html", [
      [ "StereoProcessor", "classSteinberg_1_1Vst_1_1mda_1_1StereoProcessor.html", "classSteinberg_1_1Vst_1_1mda_1_1StereoProcessor" ]
    ] ],
    [ "mdaSubSynthController.cpp", "mdaSubSynthController_8cpp.html", null ],
    [ "mdaSubSynthController.h", "mdaSubSynthController_8h.html", [
      [ "SubSynthController", "classSteinberg_1_1Vst_1_1mda_1_1SubSynthController.html", "classSteinberg_1_1Vst_1_1mda_1_1SubSynthController" ]
    ] ],
    [ "mdaSubSynthProcessor.cpp", "mdaSubSynthProcessor_8cpp.html", null ],
    [ "mdaSubSynthProcessor.h", "mdaSubSynthProcessor_8h.html", [
      [ "SubSynthProcessor", "classSteinberg_1_1Vst_1_1mda_1_1SubSynthProcessor.html", "classSteinberg_1_1Vst_1_1mda_1_1SubSynthProcessor" ]
    ] ],
    [ "mdaTalkBoxController.cpp", "mdaTalkBoxController_8cpp.html", null ],
    [ "mdaTalkBoxController.h", "mdaTalkBoxController_8h.html", [
      [ "TalkBoxController", "classSteinberg_1_1Vst_1_1mda_1_1TalkBoxController.html", "classSteinberg_1_1Vst_1_1mda_1_1TalkBoxController" ]
    ] ],
    [ "mdaTalkBoxProcessor.cpp", "mdaTalkBoxProcessor_8cpp.html", "mdaTalkBoxProcessor_8cpp" ],
    [ "mdaTalkBoxProcessor.h", "mdaTalkBoxProcessor_8h.html", [
      [ "TalkBoxProcessor", "classSteinberg_1_1Vst_1_1mda_1_1TalkBoxProcessor.html", "classSteinberg_1_1Vst_1_1mda_1_1TalkBoxProcessor" ]
    ] ],
    [ "mdaTestToneController.cpp", "mdaTestToneController_8cpp.html", "mdaTestToneController_8cpp" ],
    [ "mdaTestToneController.h", "mdaTestToneController_8h.html", [
      [ "TestToneController", "classSteinberg_1_1Vst_1_1mda_1_1TestToneController.html", "classSteinberg_1_1Vst_1_1mda_1_1TestToneController" ],
      [ "ProxyParameter", "exceptionSteinberg_1_1Vst_1_1mda_1_1ProxyParameter.html", "exceptionSteinberg_1_1Vst_1_1mda_1_1ProxyParameter" ]
    ] ],
    [ "mdaTestToneProcessor.cpp", "mdaTestToneProcessor_8cpp.html", null ],
    [ "mdaTestToneProcessor.h", "mdaTestToneProcessor_8h.html", "mdaTestToneProcessor_8h" ],
    [ "mdaThruZeroController.cpp", "mdaThruZeroController_8cpp.html", null ],
    [ "mdaThruZeroController.h", "mdaThruZeroController_8h.html", [
      [ "ThruZeroController", "classSteinberg_1_1Vst_1_1mda_1_1ThruZeroController.html", "classSteinberg_1_1Vst_1_1mda_1_1ThruZeroController" ]
    ] ],
    [ "mdaThruZeroProcessor.cpp", "mdaThruZeroProcessor_8cpp.html", "mdaThruZeroProcessor_8cpp" ],
    [ "mdaThruZeroProcessor.h", "mdaThruZeroProcessor_8h.html", [
      [ "ThruZeroProcessor", "classSteinberg_1_1Vst_1_1mda_1_1ThruZeroProcessor.html", "classSteinberg_1_1Vst_1_1mda_1_1ThruZeroProcessor" ]
    ] ],
    [ "mdaTrackerController.cpp", "mdaTrackerController_8cpp.html", null ],
    [ "mdaTrackerController.h", "mdaTrackerController_8h.html", [
      [ "TrackerController", "classSteinberg_1_1Vst_1_1mda_1_1TrackerController.html", "classSteinberg_1_1Vst_1_1mda_1_1TrackerController" ]
    ] ],
    [ "mdaTrackerProcessor.cpp", "mdaTrackerProcessor_8cpp.html", null ],
    [ "mdaTrackerProcessor.h", "mdaTrackerProcessor_8h.html", [
      [ "TrackerProcessor", "classSteinberg_1_1Vst_1_1mda_1_1TrackerProcessor.html", "classSteinberg_1_1Vst_1_1mda_1_1TrackerProcessor" ]
    ] ],
    [ "note_expression_synth_controller.cpp", "note__expression__synth__controller_8cpp.html", null ],
    [ "note_expression_synth_controller.h", "note__expression__synth__controller_8h.html", "note__expression__synth__controller_8h" ],
    [ "note_expression_synth_processor.cpp", "note__expression__synth__processor_8cpp.html", null ],
    [ "note_expression_synth_processor.h", "note__expression__synth__processor_8h.html", [
      [ "Processor", "classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1Processor.html", "classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1Processor" ]
    ] ],
    [ "note_expression_synth_ui.cpp", "note__expression__synth__ui_8cpp.html", "note__expression__synth__ui_8cpp" ],
    [ "note_expression_synth_ui.h", "note__expression__synth__ui_8h.html", [
      [ "ControllerWithUI", "classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1ControllerWithUI.html", "classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1ControllerWithUI" ],
      [ "ProcessorWithUIController", "classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1ProcessorWithUIController.html", "classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1ProcessorWithUIController" ]
    ] ],
    [ "note_expression_synth_voice.cpp", "note__expression__synth__voice_8cpp.html", null ],
    [ "note_expression_synth_voice.h", "note__expression__synth__voice_8h.html", "note__expression__synth__voice_8h" ],
    [ "note_touch_controller.cpp", "note__touch__controller_8cpp.html", "note__touch__controller_8cpp" ],
    [ "note_touch_controller.h", "note__touch__controller_8h.html", [
      [ "NoteTouchController", "classVSTGUI_1_1NoteTouchController.html", "classVSTGUI_1_1NoteTouchController" ]
    ] ],
    [ "parameterchangescheck.cpp", "parameterchangescheck_8cpp.html", null ],
    [ "parameterchangescheck.h", "parameterchangescheck_8h.html", [
      [ "ParameterChangesCheck", "classParameterChangesCheck.html", "classParameterChangesCheck" ]
    ] ],
    [ "pitchnames.cpp", "pitchnames_8cpp.html", "pitchnames_8cpp" ],
    [ "pitchnames.h", "pitchnames_8h.html", [
      [ "PitchNamesController", "classSteinberg_1_1Vst_1_1PitchNamesController.html", "classSteinberg_1_1Vst_1_1PitchNamesController" ],
      [ "PitchNamesProcessor", "classSteinberg_1_1Vst_1_1PitchNamesProcessor.html", "classSteinberg_1_1Vst_1_1PitchNamesProcessor" ]
    ] ],
    [ "pitchnamesdatabrowsersource.cpp", "pitchnamesdatabrowsersource_8cpp.html", null ],
    [ "pitchnamesdatabrowsersource.h", "pitchnamesdatabrowsersource_8h.html", [
      [ "PitchNamesDataBrowserSource", "classVSTGUI_1_1PitchNamesDataBrowserSource.html", "classVSTGUI_1_1PitchNamesDataBrowserSource" ]
    ] ],
    [ "channelcontext/source/plug.cpp", "channelcontext_2source_2plug_8cpp.html", null ],
    [ "legacymidiccout/source/plug.cpp", "legacymidiccout_2source_2plug_8cpp.html", null ],
    [ "note_expression_text/source/plug.cpp", "note__expression__text_2source_2plug_8cpp.html", null ],
    [ "prefetchablesupport/source/plug.cpp", "prefetchablesupport_2source_2plug_8cpp.html", null ],
    [ "programchange/source/plug.cpp", "programchange_2source_2plug_8cpp.html", null ],
    [ "channelcontext/source/plug.h", "channelcontext_2source_2plug_8h.html", [
      [ "Plug", "classSteinberg_1_1Vst_1_1Plug.html", "classSteinberg_1_1Vst_1_1Plug" ]
    ] ],
    [ "legacymidiccout/source/plug.h", "legacymidiccout_2source_2plug_8h.html", [
      [ "Plug", "classSteinberg_1_1Vst_1_1LegacyMIDICCOut_1_1Plug.html", "classSteinberg_1_1Vst_1_1LegacyMIDICCOut_1_1Plug" ]
    ] ],
    [ "note_expression_text/source/plug.h", "note__expression__text_2source_2plug_8h.html", [
      [ "Plug", "classSteinberg_1_1Vst_1_1Plug.html", "classSteinberg_1_1Vst_1_1Plug" ]
    ] ],
    [ "prefetchablesupport/source/plug.h", "prefetchablesupport_2source_2plug_8h.html", [
      [ "Plug", "classSteinberg_1_1Vst_1_1Plug.html", "classSteinberg_1_1Vst_1_1Plug" ]
    ] ],
    [ "programchange/source/plug.h", "programchange_2source_2plug_8h.html", [
      [ "Plug", "classSteinberg_1_1Vst_1_1Plug.html", "classSteinberg_1_1Vst_1_1Plug" ]
    ] ],
    [ "channelcontext/source/plugcids.h", "channelcontext_2source_2plugcids_8h.html", null ],
    [ "legacymidiccout/source/plugcids.h", "legacymidiccout_2source_2plugcids_8h.html", null ],
    [ "note_expression_text/source/plugcids.h", "note__expression__text_2source_2plugcids_8h.html", null ],
    [ "prefetchablesupport/source/plugcids.h", "prefetchablesupport_2source_2plugcids_8h.html", null ],
    [ "programchange/source/plugcids.h", "programchange_2source_2plugcids_8h.html", null ],
    [ "channelcontext/source/plugcontroller.cpp", "channelcontext_2source_2plugcontroller_8cpp.html", null ],
    [ "legacymidiccout/source/plugcontroller.cpp", "legacymidiccout_2source_2plugcontroller_8cpp.html", null ],
    [ "note_expression_text/source/plugcontroller.cpp", "note__expression__text_2source_2plugcontroller_8cpp.html", null ],
    [ "panner/source/plugcontroller.cpp", "panner_2source_2plugcontroller_8cpp.html", null ],
    [ "prefetchablesupport/source/plugcontroller.cpp", "prefetchablesupport_2source_2plugcontroller_8cpp.html", null ],
    [ "programchange/source/plugcontroller.cpp", "programchange_2source_2plugcontroller_8cpp.html", null ],
    [ "channelcontext/source/plugcontroller.h", "channelcontext_2source_2plugcontroller_8h.html", [
      [ "PlugController", "classSteinberg_1_1Vst_1_1PlugController.html", "classSteinberg_1_1Vst_1_1PlugController" ]
    ] ],
    [ "legacymidiccout/source/plugcontroller.h", "legacymidiccout_2source_2plugcontroller_8h.html", [
      [ "PlugController", "classSteinberg_1_1Vst_1_1LegacyMIDICCOut_1_1PlugController.html", "classSteinberg_1_1Vst_1_1LegacyMIDICCOut_1_1PlugController" ]
    ] ],
    [ "note_expression_text/source/plugcontroller.h", "note__expression__text_2source_2plugcontroller_8h.html", [
      [ "PlugController", "classSteinberg_1_1Vst_1_1PlugController.html", "classSteinberg_1_1Vst_1_1PlugController" ]
    ] ],
    [ "prefetchablesupport/source/plugcontroller.h", "prefetchablesupport_2source_2plugcontroller_8h.html", [
      [ "PlugController", "classSteinberg_1_1Vst_1_1PlugController.html", "classSteinberg_1_1Vst_1_1PlugController" ]
    ] ],
    [ "programchange/source/plugcontroller.h", "programchange_2source_2plugcontroller_8h.html", [
      [ "PlugController", "classSteinberg_1_1Vst_1_1PlugController.html", "classSteinberg_1_1Vst_1_1PlugController" ]
    ] ],
    [ "channelcontext/source/plugentry.cpp", "channelcontext_2source_2plugentry_8cpp.html", "channelcontext_2source_2plugentry_8cpp" ],
    [ "legacymidiccout/source/plugentry.cpp", "legacymidiccout_2source_2plugentry_8cpp.html", "legacymidiccout_2source_2plugentry_8cpp" ],
    [ "note_expression_text/source/plugentry.cpp", "note__expression__text_2source_2plugentry_8cpp.html", "note__expression__text_2source_2plugentry_8cpp" ],
    [ "prefetchablesupport/source/plugentry.cpp", "prefetchablesupport_2source_2plugentry_8cpp.html", "prefetchablesupport_2source_2plugentry_8cpp" ],
    [ "programchange/source/plugentry.cpp", "programchange_2source_2plugentry_8cpp.html", "programchange_2source_2plugentry_8cpp" ],
    [ "plugfactory.cpp", "plugfactory_8cpp.html", "plugfactory_8cpp" ],
    [ "channelcontext/source/plugparamids.h", "channelcontext_2source_2plugparamids_8h.html", "channelcontext_2source_2plugparamids_8h" ],
    [ "legacymidiccout/source/plugparamids.h", "legacymidiccout_2source_2plugparamids_8h.html", "legacymidiccout_2source_2plugparamids_8h" ],
    [ "note_expression_text/source/plugparamids.h", "note__expression__text_2source_2plugparamids_8h.html", "note__expression__text_2source_2plugparamids_8h" ],
    [ "prefetchablesupport/source/plugparamids.h", "prefetchablesupport_2source_2plugparamids_8h.html", "prefetchablesupport_2source_2plugparamids_8h" ],
    [ "programchange/source/plugparamids.h", "programchange_2source_2plugparamids_8h.html", "programchange_2source_2plugparamids_8h" ],
    [ "plugprocessor.cpp", "plugprocessor_8cpp.html", "plugprocessor_8cpp" ],
    [ "processcontextcheck.cpp", "processcontextcheck_8cpp.html", null ],
    [ "processcontextcheck.h", "processcontextcheck_8h.html", [
      [ "ProcessContextCheck", "classProcessContextCheck.html", "classProcessContextCheck" ]
    ] ],
    [ "processsetupcheck.cpp", "processsetupcheck_8cpp.html", null ],
    [ "processsetupcheck.h", "processsetupcheck_8h.html", [
      [ "ProcessSetupCheck", "classProcessSetupCheck.html", "classProcessSetupCheck" ]
    ] ],
    [ "sync.h", "sync_8h.html", "sync_8h" ],
    [ "syncdelaycontroller.cpp", "syncdelaycontroller_8cpp.html", null ],
    [ "syncdelaycontroller.h", "syncdelaycontroller_8h.html", [
      [ "SyncDelayController", "classSteinberg_1_1Vst_1_1SyncDelayController.html", "classSteinberg_1_1Vst_1_1SyncDelayController" ]
    ] ],
    [ "syncdelayfactory.cpp", "syncdelayfactory_8cpp.html", "syncdelayfactory_8cpp" ],
    [ "syncdelayids.h", "syncdelayids_8h.html", "syncdelayids_8h" ],
    [ "syncdelayprocessor.cpp", "syncdelayprocessor_8cpp.html", null ],
    [ "syncdelayprocessor.h", "syncdelayprocessor_8h.html", [
      [ "SyncDelayProcessor", "classSteinberg_1_1Vst_1_1SyncDelayProcessor.html", "classSteinberg_1_1Vst_1_1SyncDelayProcessor" ]
    ] ],
    [ "syncdelayversion.h", "syncdelayversion_8h.html", "syncdelayversion_8h" ],
    [ "testsuite.h", "testsuite_8h.html", [
      [ "TestSuite", "classSteinberg_1_1Vst_1_1TestSuite.html", "classSteinberg_1_1Vst_1_1TestSuite" ],
      [ "Test", "classSteinberg_1_1Vst_1_1TestSuite_1_1Test.html", "classSteinberg_1_1Vst_1_1TestSuite_1_1Test" ]
    ] ],
    [ "audiohost/source/usediids.cpp", "audiohost_2source_2usediids_8cpp.html", null ],
    [ "editorhost/source/usediids.cpp", "editorhost_2source_2usediids_8cpp.html", null ],
    [ "validator/source/usediids.cpp", "validator_2source_2usediids_8cpp.html", null ],
    [ "validator.cpp", "validator_8cpp.html", null ],
    [ "validator.h", "validator_8h.html", [
      [ "Validator", "classSteinberg_1_1Vst_1_1Validator.html", "classSteinberg_1_1Vst_1_1Validator" ],
      [ "ModuleTestConfig", "structSteinberg_1_1Vst_1_1Validator_1_1ModuleTestConfig.html", "structSteinberg_1_1Vst_1_1Validator_1_1ModuleTestConfig" ],
      [ "VstModule", "classSteinberg_1_1Vst_1_1VstModule.html", "classSteinberg_1_1Vst_1_1VstModule" ]
    ] ],
    [ "adelay/source/version.h", "adelay_2source_2version_8h.html", "adelay_2source_2version_8h" ],
    [ "again/source/version.h", "again_2source_2version_8h.html", "again_2source_2version_8h" ],
    [ "channelcontext/source/version.h", "channelcontext_2source_2version_8h.html", "channelcontext_2source_2version_8h" ],
    [ "hostchecker/source/version.h", "hostchecker_2source_2version_8h.html", "hostchecker_2source_2version_8h" ],
    [ "legacymidiccout/source/version.h", "legacymidiccout_2source_2version_8h.html", "legacymidiccout_2source_2version_8h" ],
    [ "mda-vst3/source/version.h", "mda-vst3_2source_2version_8h.html", "mda-vst3_2source_2version_8h" ],
    [ "note_expression_synth/source/version.h", "note__expression__synth_2source_2version_8h.html", "note__expression__synth_2source_2version_8h" ],
    [ "note_expression_text/source/version.h", "note__expression__text_2source_2version_8h.html", "note__expression__text_2source_2version_8h" ],
    [ "pitchnames/source/version.h", "pitchnames_2source_2version_8h.html", "pitchnames_2source_2version_8h" ],
    [ "prefetchablesupport/source/version.h", "prefetchablesupport_2source_2version_8h.html", "prefetchablesupport_2source_2version_8h" ],
    [ "programchange/source/version.h", "programchange_2source_2version_8h.html", "programchange_2source_2version_8h" ],
    [ "voicebase.h", "voicebase_8h.html", "voicebase_8h" ],
    [ "voiceprocessor.h", "voiceprocessor_8h.html", "voiceprocessor_8h" ],
    [ "VSTInterAppAudioAppDelegate.h", "VSTInterAppAudioAppDelegate_8h.html", [
      [ "VSTInterAppAudioAppDelegate", "interfaceVSTInterAppAudioAppDelegate.html", null ]
    ] ],
    [ "VSTInterAppAudioAppDelegate.mm", "VSTInterAppAudioAppDelegate_8mm.html", null ],
    [ "VSTInterAppAudioHostUIControllerViewController.h", "VSTInterAppAudioHostUIControllerViewController_8h.html", [
      [ "VSTInterAppAudioHostUIControllerViewController", "interfaceVSTInterAppAudioHostUIControllerViewController.html", "interfaceVSTInterAppAudioHostUIControllerViewController" ]
    ] ],
    [ "VSTInterAppAudioHostUIControllerViewController.mm", "VSTInterAppAudioHostUIControllerViewController_8mm.html", null ]
];